@@ -1,7 +1,5 @@
 /******************************************************************************
- * mod_uploader / MmapFileWriter.h
- ******************************************************************************
- * Copyright (C) 2005 Tetsuya Kimata <kimata@acapulco.dyndns.org>
+ * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
  *
  * All rights reserved.
  *
@@ -24,100 +22,88 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MmapFileWriter.h 1003 2006-03-14 13:52:47Z svn $
+ * $Id: MmapFileWriter.h 2035 2006-11-23 16:14:21Z svn $
  *****************************************************************************/
 
 #ifndef MMAP_FILE_WRITER_H
 #define MMAP_FILE_WRITER_H
 
-#include "FileWriter.h"
-
-#include "apr_mmap.h"
-#include "apr_pools.h"
+#include "Environment.h"
 
 #include <cstdlib>
 
-#ifdef HAVE_CONFIG_H
-#include "mod_uploader_config.h"
-#endif
+#include "apr_mmap.h"
+
+#include "FileWriter.h"
 
 using namespace std;
 
 /**
- * @brief mmap Ȥäơեإǡ񤭽Ф饹
+ * @brief mmap を使って，ファイルへデータを書き出すクラス．
  */
 class MmapFileWriter: public FileWriter
 {
 public:
+    static const apr_int32_t OPEN_FLAG;
     /**
-     * 󥹥ȥ饯
+     * コンストラクタ．
      *
-     * offset ꤵƤϡΰְʹߤ˽񤭽ФԤޤ
+     * offset が指定されている場合は，その位置以降に書き出しを行います．
      *
-     * @param[in] pool ס
-     * @param[in] fd եϥɥ
-     * @param[in] offset 񤭽Ф򳫻Ϥ
+     * @param[in] pool プール
+     * @param[in] file ファイルハンドラ
+     * @param[in] offset 書き出しを開始する位置
      */
-    MmapFileWriter(apr_pool_t *pool, apr_file_t *fd, apr_size_t offset=0);
+    MmapFileWriter(apr_pool_t *pool, apr_file_t *file, apr_size_t offset=0);
     /**
-     * եؤν񤭽ФԤޤ
+     * ファイルを閉じます．
      *
-     * @param[in] buf 񤭽Фǡ
-     * @param[in] size 񤭽Ф
-     * @exception const char * 񤭽Ф˼Ԥ
-     */
-    void write(const void *buf, apr_size_t size);
-    /**
-     * եĤޤ
-     *
-     * @exception const char * ĤΤ˼Ԥ
+     * @exception const char * 閉じるのに失敗した場合
      */
     void close();
     /**
-     * ǥȥ饯
+     * デストラクタ．
      *
-     * եĤޤ
+     * ファイルを閉じます．
      */
     ~MmapFileWriter();
 
 private:
     /**
-     * mmap ˤƤΥ֥å
+     * ファイルへの書き出しを行います．
      *
-     * Ǥϡ٤ write 륵 BLOCK_SIZE 
-     * ꤷƤޤ
+     * @param[in] buffer 書き出すデータ
+     * @param[in] size 書き出すサイズ
+     * @exception const char * 書き出しに失敗した場合
      */
-    static const apr_size_t BLOCK_SIZE;
+    void write_impl(const void *buffer, apr_size_t size);
     /**
-     * OS Υڡ
+     * OS のページサイズ
      *
-     * getpagesize(2) ȤФͤѤ롥
+     * getpagesize(2) が使えればその返値が用いられる．
      */
     static const apr_size_t PAGE_SIZE;
+    /**
+     * mmap によるメモリ割り当てのブロックサイズ候補
+     */
+    static const apr_size_t BLOCK_SIZE;
 
     /**
-     * ߤΥޥåԥ󥰤ơΥ֥å֤ޥåפޤ
+     * 現在のマッピングを解除して，次のブロック位置をマップします．
      */
     void expand();
 
-    MmapFileWriter(const MmapFileWriter&);
-    MmapFileWriter &operator=(const MmapFileWriter&);
-
-    /** mmap ξ */
+    /** mmap の情報 */
     apr_mmap_t *file_map_;
-    /** ߥޥåפƤ֥åΥǥå */
-    apr_uint64_t offset_factor_;
-    /** mmap ˤƤΥ֥å */
-    const apr_size_t block_size_;
-    /** ˽񤭹֥åΰ */
+    /** 現在マップしているブロックのインデックス */
+    apr_uint64_t block_index_;
+    /** 次に書き込むブロック中の位置 */
     apr_size_t block_offset_;
-    /** ˥ե뤬 close 줿ɤ */
-    bool is_closed_;
 };
 
 #endif
 
 // Local Variables:
 // mode: c++
-// buffer-file-coding-system: euc-japan-dos
+// coding: utf-8-dos
 // End:
