@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.h 2098 2006-11-26 09:11:25Z svn $
+ * $Id: UploadItemList.h 2144 2006-11-29 14:54:20Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_HEADER_LIST_H
@@ -111,7 +111,7 @@ public:
      */
     static apr_size_t get_memory_size(apr_size_t max_list_size);
     static void dump_header_list(apr_pool_t *pool,
-                                 UploadItemList *item_list);
+                                 UploadItemList *list);
 
 private:
     /**
