@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.h 2124 2006-11-27 16:14:24Z svn $
+ * $Id: UploaderConfig.h 2144 2006-11-29 14:54:20Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADER_CONFIG_H
@@ -39,9 +39,12 @@
 
 class PostFlowController;
 class UploadItemList;
+class ThumbnailList;
 class UploadItemManager;
 class UploaderTemplate;
 
+#include "ThumbnailList.h"
+
 using namespace std;
 
 /**
@@ -91,6 +94,11 @@ public:
     {
         return item_list_;
     };
+    ThumbnailList *get_thumbnail_list() const
+    {
+        return thumbnail_list_;
+    };
+
     UploadItemManager *get_item_manager() const
     {
         return item_manager_;
@@ -130,11 +138,13 @@ private:
 
     apr_pool_t *pool_;
 
-    apr_shm_t *list_shm_;
-    apr_shm_t *manager_shm_;
+    apr_shm_t *item_list_shm_;
+    apr_shm_t *thumbnail_list_shm_;
+    apr_shm_t *item_manager_shm_;
     apr_shm_t *flow_controller_shm_;
 
     UploadItemList *item_list_;
+    ThumbnailList *thumbnail_list_;
     UploadItemManager *item_manager_;
     PostFlowController *flow_controller_;
 
