@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.cpp 2096 2006-11-26 08:43:57Z svn $
+ * $Id: UploadItem.cpp 2148 2006-12-01 18:06:29Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -40,7 +40,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItem.cpp 2096 2006-11-26 08:43:57Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItem.cpp 2148 2006-12-01 18:06:29Z svn $");
 
 #define AS_BCOMMENT(pointer)        reinterpret_cast<bbs_comment_t *>(pointer)
 #define UINT16(pointer)             static_cast<apr_uint16_t>(pointer)
@@ -70,12 +70,18 @@ UploadItem *UploadItem::get_instance(void *memory, apr_size_t item_id,
     const char *file_ext;
     TemporaryPool temp_pool;
 
+    cout << "UploadItem::get_instance" << endl;
+    cerr << "UploadItem::get_instance" << endl;
+
     if (is_need_validate) {
         PostDataChecker::validate_uitem(temp_pool.get(), file_size, mtime,
                                         file_name, file_mime, file_digest,
                                         remove_pass, download_pass, &comment);
     }
 
+    cout << "UploadItem::get_instance 2" << endl;
+    cerr << "UploadItem::get_instance 2" << endl;
+
     memset(memory, 0, sizeof(UploadItem));
     uitem = new(memory) UploadItem;
 
@@ -109,7 +115,8 @@ UploadItem *UploadItem::get_instance(apr_pool_t *pool, apr_size_t item_id,
                                      const char *file_digest,
                                      const char *remove_pass,
                                      const char *download_pass,
-                                     const char *comment)
+                                     const char *comment,
+                                     bool is_need_validate)
 {
     void *memory;
 
@@ -117,7 +124,7 @@ UploadItem *UploadItem::get_instance(apr_pool_t *pool, apr_size_t item_id,
 
     return get_instance(memory, item_id, item_index, file_size, mtime,
                         ip_address, file_name, file_mime, file_digest,
-                        remove_pass, download_pass, comment, false);
+                        remove_pass, download_pass, comment, is_need_validate);
 }
 
 
